\name{parseFeatures}
\alias{parseFeatures}
\title{
  Parse an experiment using a list of features
}

\description{
  This function produces the list object that contains all the
  information necessary to produce a metagene-like plot with the
  \code{plotGraphic} function. Currently supported species are: 
  \dQuote{mouse}, \dQuote{human} (default).
}

\usage{
  parseFeatures(
    bamFiles, 
    features=NULL, 
    specie="human", 
    maxDistance=5000, 
    design=NULL, 
    cores=1,
    debug=FALSE)
}

\arguments{
  \item{bamFiles}{A \code{vector} of BAM files to plot. All BAM files 
    must exist.}

  \item{features}{Either a filename of a \code{vector} of filenames.
    Supported features: ensembl_gene_id. 
    If value is NULL, all known RefSeq genes will be used.}

  \item{specie}{human: Homo sapiens (default). mouse: Mus musculus.}

  \item{maxDistance}{The distance around feature to include 
    in the plot. The maximum distance has to be a positive 
    integer.}

  \item{design}{A \code{data.frame} explaining the relationship
    between multiple samples. One line per samples. One column
    per group of samples. For example, biological replicates and
    corresponding controls are in the same group.
    1: treatment file(s). 2: control file(s).}

  \item{cores}{Number of cores for parallel processing.
    Require parallel package. The number of cores has to be a positive 
    integer.}

  \item{debug}{Keep the intermediate files (can use a lot of memory).
    TRUE or FALSE.}
}

\details{
  This function will extract the read density from alignments
  files (bam) in the viscinity of transcription start sites of
  one or multiple list of genes.

  The values are normalized as read per millions aligned (RPM).

  It is possible to parse multiple groups of gene by saving each
  list in a separate file and by listing the file names in a
  vector as the \code{features} parameter.

  By using the \code{design} parameter, the \code{parseFeatures}
  function will deal with more complex experimental design such
  as the use of replicates and/or controls. The values of
  controls are substracted from every replicates.
}

\value{
  \code{parseFeatures} returns a list that contains the data
  necessary to produce a plot.

  The data structure is a list of lists.

  The first level contain the following fields:
  \itemize{
    \item design: The information from the design file.
    \item param: The values of the argument used with parseFeatures.
    \item bamFilesDescription: A \code{data.frame} with the
      following columns:
      \itemize{
        \item bam: The names of the sorted bam files
        \item oldBam: The names of the original bam files 
        \item alignedCount: The number of aligned reads
        }
    \item matrix: A list of matrix that will be used to produce the
        plot. One element by combination of features/design
        groups.
  }
}

\author{
  Charles Joly Beauparlant
  <Charles.Joly-Beauparlant@crchul.ulaval.ca>
}

\examples{
  bamFileName <- system.file("extdata/align1_rep1.bam", package="metagene")
  featuresFileName <- system.file("extdata/list1.txt", package="metagene")
  groups <- parseFeatures(bamFileName, featuresFileName, specie="mouse")
}
